Index: webrtc/api/objc/RTCVideoSource.h |
diff --git a/webrtc/api/objc/RTCMediaSource.h b/webrtc/api/objc/RTCVideoSource.h |
similarity index 89% |
rename from webrtc/api/objc/RTCMediaSource.h |
rename to webrtc/api/objc/RTCVideoSource.h |
index 0b36b8d7093543c803f6097d28488efef8678306..a98fa6c6bba626c52ea4331bb1b3d4d6bd0bd1a9 100644 |
--- a/webrtc/api/objc/RTCMediaSource.h |
+++ b/webrtc/api/objc/RTCVideoSource.h |
@@ -19,9 +19,9 @@ typedef NS_ENUM(NSInteger, RTCSourceState) { |
NS_ASSUME_NONNULL_BEGIN |
-@interface RTCMediaSource : NSObject |
+@interface RTCVideoSource : NSObject |
-/** The current state of the RTCMediaSource. */ |
+/** The current state of the RTCVideoSource. */ |
@property(nonatomic, readonly) RTCSourceState state; |
- (instancetype)init NS_UNAVAILABLE; |